@@ -1,4 +1,5 @@
-from typing import Any
+import re
+from typing import Any, Pattern
 
 from pycfmodel.constants import CONDITION_FUNCTIONS, IMPLEMENTED_FUNCTIONS
 
@@ -14,3 +15,13 @@ def is_conditional_dict(value: Any) -> bool:
                 return False
         return True
     return False
+
+
+def regex_from_cf_string(action: str) -> Pattern:
+    # Replace *
+    action = action.replace("*", ".*")
+
+    # Replace ?
+    action = action.replace("?", ".{1}")
+
+    return re.compile(f"^{action}$", re.IGNORECASE)
