@@ -1,6 +1,7 @@
 import pytest
 
 from pycfmodel.model.resources.sns_topic_policy import SNSTopicPolicy
+from pycfmodel.model.utils import OptionallyNamedPolicyDocument
 
 
 @pytest.fixture()
@@ -29,3 +30,9 @@ def sns_topic_policy():
 def test_sns_topic_policy(sns_topic_policy):
     assert len(sns_topic_policy.Properties.Topics) == 1
     assert sns_topic_policy.Properties.PolicyDocument.Statement.Effect == "Allow"
+
+
+def test_sns_policy_documents(sns_topic_policy):
+    assert sns_topic_policy.policy_documents == [
+        OptionallyNamedPolicyDocument(name=None, policy_document=sns_topic_policy.Properties.PolicyDocument)
+    ]
